Package 'NBDCtoolsData'

Title: NBDCtoolsData: NBDC Data Hub Tools (Data Package)
Description: This package provides data elements for the NBDCtools package. Data Hub.
Authors: Le Zhang [aut, cre] (ORCID: <https://orcid.org/0009-0008-0205-2150>), Janosch Linkersdoerfer [aut] (ORCID: <https://orcid.org/0000-0002-1577-1233>)
Maintainer: Le Zhang <[email protected]>
License: GPL (>= 3)
Version: 5.0.0
Built: 2026-05-15 22:04:49 UTC
Source: https://github.com/nbdc-datahub/NBDCtoolsData

Help Index


List of data dictionaries

Description

List of data dictionaries

Usage

lst_dds

Format

A list of data dictionaries for the NBDC Data Hub studies. First level of the list is the study name (currently ABCD & HBCD), and the second level is the version/release of the study.

- lst_dds
    |- abcd
         |- 6.0
         |   |- data dictionary dataframe
         |- ...
    |- hbcd
         |- 1.0
         |   |- data dictionary dataframe
         |- ...

List of levels

Description

List of levels

Usage

lst_levels

Format

A list of categorical levels tables for the NBDC Data Hub studies. First level of the list is the study name (currently ABCD & HBCD), and the second level is the version/release of the study.

- lst_levels
    |- abcd
         |- 6.0
         |   |- levels dataframe
         |- ...
    |- hbcd
         |- 1.0
         |   |- levels dataframe
         |- ...

List of latest session mappings

Description

List of latest session mappings

Usage

lst_session_latest

Format

A list mapping each study and release to the latest available session metadata used by NBDCtools. First level of the list is the study name (currently ABCD & HBCD), and the second level is the version/release of the study. Each release contains:

table_name

Character scalar with the table used for lookup.

session

Character scalar with the latest session label.

- lst_session_latest
    |- abcd
         |- 6.0
         |   |- table_name: "ab_g_dyn"
         |   |- session: "ses-06A"
         |- ...
    |- hbcd
         |- 1.0
         |   |- table_name: "par_visit_data"
         |   |- session: "ses-V03"
         |- ...

List of sessions

Description

List of sessions

Usage

lst_sessions

Format

A list of session metadata for the NBDC Data Hub studies. First level of the list is the study name (currently ABCD & HBCD), and the second level is the version/release of the study.

- lst_sessions
    |- abcd
         |- 6.0
         |   |- sessions dataframe
         |- ...
    |- hbcd
         |- 1.0
         |   |- sessions dataframe
         |- ...